@@ -3,8 +3,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Algebraic_kernel_d/include/CGAL/Algebraic_kernel_d/Algebraic_real_rep.h $
-// $Id: Algebraic_real_rep.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Algebraic_kernel_d/include/CGAL/Algebraic_kernel_d/Algebraic_real_rep.h $
+// $Id: include/CGAL/Algebraic_kernel_d/Algebraic_real_rep.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -23,7 +23,7 @@
 #include <CGAL/basic.h>
 #include <CGAL/Polynomial_type_generator.h>
 #include <CGAL/Polynomial_traits_d.h>
-#include <boost/optional.hpp>
+#include <optional>
 
 namespace CGAL {
 
@@ -38,7 +38,7 @@ namespace internal {
 // sign_at_low_ = polynomial_.evaluate(low_)
 // x is the only root of polynomial_ in the open interval ]low_,high_[
 // low_ != x != high
-// ******************* EXEPTION *******************
+// ******************* EXCEPTION *******************
 // x is rational: in this case low=high=x
 
 template< class Coefficient_, class Rational_>
@@ -56,7 +56,7 @@ private:
 
     typedef Algebraic_real_rep <Coefficient,Rational>     Self;
 public:
-    typedef boost::optional< std::pair<double, double> >                  Interval_option;
+    typedef std::optional< std::pair<double, double> >                  Interval_option;
 
     mutable Poly polynomial_;                //!< square free polynomial
     mutable Rational low_;                      //!< lower endpoint of interval
@@ -135,7 +135,7 @@ protected:
 
         // interval_option left out
 
-        // trys to set rational if degree is 1
+        // tries to set rational if degree is 1
         typedef typename CGAL::Coercion_traits< Coefficient, Rational >::Type RET;
         set_rational(RET());
     }
