@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5/Intersections_2/include/CGAL/Intersections_2/Iso_rectangle_2_Iso_rectangle_2.h $
-// $Id: Iso_rectangle_2_Iso_rectangle_2.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Intersections_2/include/CGAL/Intersections_2/Iso_rectangle_2_Iso_rectangle_2.h $
+// $Id: include/CGAL/Intersections_2/Iso_rectangle_2_Iso_rectangle_2.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -74,20 +74,20 @@ intersection(
 }
 
 template<typename K>
-inline bool
-do_intersect(const typename K::Iso_rectangle_2 &irect1,
-             const typename K::Iso_rectangle_2 &irect2,
-             const K&) {
+typename K::Boolean
+do_intersect(const typename K::Iso_rectangle_2& irect1,
+             const typename K::Iso_rectangle_2& irect2,
+             const K&)
+{
   return bool(intersection(irect1, irect2));
 }
 
 } // namespace internal
 } // namespace Intersections
 
-
 CGAL_INTERSECTION_FUNCTION_SELF(Iso_rectangle_2, 2)
 CGAL_DO_INTERSECT_FUNCTION_SELF(Iso_rectangle_2, 2)
 
-} //namespace CGAL
+} // namespace CGAL
 
-#endif
+#endif // CGAL_INTERSECTIONS_2_ISO_RECTANGLE_2_ISO_RECTANGLE_2_H
