@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Intersections_2/include/CGAL/Intersections_2/Line_2_Point_2.h $
-// $Id: Line_2_Point_2.h 0779373 2020-03-26T13:31:46+01:00 Sébastien Loriot
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Intersections_2/include/CGAL/Intersections_2/Line_2_Point_2.h $
+// $Id: include/CGAL/Intersections_2/Line_2_Point_2.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -29,21 +29,23 @@ namespace Intersections {
 namespace internal {
 
 template <class K>
-inline bool
-do_intersect(const typename K::Point_2 &pt,
-             const typename K::Line_2 &line,
+inline
+typename K::Boolean
+do_intersect(const typename K::Point_2& pt,
+             const typename K::Line_2& line,
              const K&)
 {
-    return line.has_on(pt);
+  return line.has_on(pt);
 }
 
 template <class K>
-inline bool
-do_intersect(const typename K::Line_2 &line,
-             const typename K::Point_2 &pt,
+inline
+typename K::Boolean
+do_intersect(const typename K::Line_2& line,
+             const typename K::Point_2& pt,
              const K&)
 {
-    return line.has_on(pt);
+  return line.has_on(pt);
 }
 
 template <class K>
@@ -76,6 +78,6 @@ intersection(const typename K::Line_2 &line,
 CGAL_INTERSECTION_FUNCTION(Point_2, Line_2, 2)
 CGAL_DO_INTERSECT_FUNCTION(Point_2, Line_2, 2)
 
-} //namespace CGAL
+} // namespace CGAL
 
-#endif
+#endif // CGAL_INTERSECTIONS_2_POINT_2_LINE_2_H
