@@ -7,8 +7,8 @@
 //
 // This file is part of CGAL (www.cgal.org)
 //
-// $URL: https://github.com/CGAL/cgal/blob/v5.5.2/Kernel_23/include/CGAL/Weighted_point_2.h $
-// $Id: Weighted_point_2.h e7357ac 2021-07-19T14:53:27+02:00 Marc Glisse
+// $URL: https://github.com/CGAL/cgal/blob/v6.0/Kernel_23/include/CGAL/Weighted_point_2.h $
+// $Id: include/CGAL/Weighted_point_2.h 50219fc33bc $
 // SPDX-License-Identifier: LGPL-3.0-or-later OR LicenseRef-Commercial
 //
 //
@@ -20,7 +20,6 @@
 #include <CGAL/Origin.h>
 #include <CGAL/representation_tags.h>
 #include <CGAL/assertions.h>
-#include <boost/type_traits/is_same.hpp>
 #include <CGAL/Kernel/Return_base_tag.h>
 #include <CGAL/Bbox_2.h>
 #include <CGAL/Dimension.h>
@@ -35,7 +34,7 @@ class Weighted_point_2 : public R_::Kernel_base::Weighted_point_2
   typedef typename R_::FT                             RT;
 
   typedef Weighted_point_2<R_>                        Self;
-  CGAL_static_assertion((boost::is_same<Self, typename R_::Weighted_point_2>::value));
+  static_assert(std::is_same<Self, typename R_::Weighted_point_2>::value);
 
 public:
   typedef Dimension_tag<2>                            Ambient_dimension;
